<?php

use WPEssential\Plugins\Panel\Fields\Textarea;
use WPEssential\Plugins\Panel\Section;

return Section::make( __( 'Textarea', 'wpessential' ), 'textarea_field' )
              ->description( __( 'Textarea fields examples.', 'wpessential' ) )
              ->icon_type( 'icon' )
              ->icon( 'location' )
              ->note_desc( __( 'Textarea fields examples.', 'wpessential' ) )
              ->note_icon( 'location' )
              ->note_title( 'Textarea' )
              ->priority( 10 )
              ->controls( [
	              Textarea::make( __( 'Textarea field', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->default( 'Im default value of this field' )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with max value', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->default( 'Im default value of this field' )
	                      ->maxlength( 50 )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with max/min value', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->maxlength( 50 )
	                      ->minlength( 5 )
	                      ->default( 'Im default value of this field' )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with word limit show', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->default( 'Im default value of this field' )
	                      ->maxlength( 50 )
	                      ->minlength( 5 )
	                      ->show_word_limit( true )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with clear icon', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->default( 'Im default value of this field' )
	                      ->clearable( true )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with disable', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->default( 'Im default value of this field' )
	                      ->disabled( true )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with read only', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->default( 'Im default value of this field' )
	                      ->readonly( true )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with large size', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->size( 'large' )
	                      ->default( 'Im default value of this field' )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with small size', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->size( 'small' )
	                      ->default( 'Im default value of this field' )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with default size', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->size( 'default' )
	                      ->default( 'Im default value of this field' )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with empty size', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->size( '' )
	                      ->default( 'Im default value of this field' )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with resize', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->resize( 'both' )
	                      ->default( 'Im default value of this field' )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with info', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->default( 'Im default value of this field' )
	                      ->note_title( __( 'WPE ', 'wpessential' ) )
	                      ->note_icon( 'info' )
	                      ->note_desc( __( 'Example desc of the panel.', 'wpessential' ) )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with rows', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->default( 'Im default value of this field' )
	                      ->note_title( __( 'WPE ', 'wpessential' ) )
	                      ->note_desc( __( 'Example desc of the panel.', 'wpessential' ) )
	                      ->rows( 10 )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with min rows', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->default( 'Im default value of this field' )
	                      ->note_title( __( 'WPE ', 'wpessential' ) )
	                      ->note_desc( __( 'Example desc of the panel.', 'wpessential' ) )
	                      ->min_rows( 1 )
	                      ->toArray(),
	              Textarea::make( __( 'Textarea field with max rows', 'wpessential' ) )
	                      ->subtitle( __( 'Field Subtitle' ) )
	                      ->description( __( 'Field description' ) )
	                      ->placeholder( __( 'Field placeholder', 'wpessential' ) )
	                      ->default( 'Im default value of this field' )
	                      ->note_title( __( 'WPE ', 'wpessential' ) )
	                      ->note_desc( __( 'Example desc of the panel.', 'wpessential' ) )
	                      ->max_rows( 2 )
	                      ->toArray()
              ] )
              ->toArray();
